@@ -25,12 +25,10 @@
 #' @param ci coverage probability for credible intervals, default = 0.95
 #' @param n.digits number of digits to keep in the final estimation of treatment effect
 #' @param x an object of class "`BJSM_c`", usually, a result of a call to \code{\link{BJSM_c}}
-#' @param cran_check_option TRUE or FALSE. If FALSE, the algorithm will fit a
-#'  model like usual. This should be the default for all model fitting.
-#'  If TRUE, the model fitting is bypassed to pass CRAN check.
 #' @param verbose TRUE or FALSE. If FALSE, no function message and progress bar will be
 #'  printed.
-#' @param ... optional arguments that are passed to \code{jags.model()} function.
+#' @param jags.model_options a list of optional arguments that are passed to \code{jags.model()} function.
+#' @param coda.samples_options a list of optional arguments that are passed to \code{coda.samples()} function.
 
 #'
 #' @details
@@ -39,11 +37,10 @@
 #'
 #' Note that this package does not include the JAGS library, users need to install JAGS separately. Please check this page for more details: \url{https://sourceforge.net/projects/mcmc-jags/}
 #' @return
-#' \describe{
-#'     \item{posterior_sample}{an \code{mcmc.list} object generated through the \code{coda.samples()} function,
+#' \item{posterior_sample}{an \code{mcmc.list} object generated through the \code{coda.samples()} function,
 #'    which includes posterior samples of the link parameters and response rates generated through the MCMC
 #'    process}
-#'     \item{mean_estimate}{BJSM estimate of each parameter:
+#' \item{mean_estimate}{BJSM estimate of each parameter:
 #'     \enumerate{
 #'          \item \code{phi1} - lingering effect of the first treatment
 #'          \item `phi3` - if the patient stays on the same treatment, \code{phi3} is the cumulative effect of stage 1 that occurs on the treatment longer term
@@ -51,10 +48,9 @@
 #'          \item \code{rho} is the inverse of the variance-covariance matrix of the multivariate distribution, first parameter indicates whether patient stayed on the same treatment (2) or not (1), second parameter
 #' indicates the row number of the inverse of variance-covariance matrix, and the third parameter indicates the column number of the inverse of the variance-covariance matrix}
 #'    }
-#'     \item{ci_estimate}{x% credible interval for each parameter. By default round to
+#' \item{ci_estimate}{x% credible interval for each parameter. By default round to
 #'     2 decimal places, if more decimals are needed, please access the results by
 #'     `[YourResultName]$ci_estimates$CI_low` or `[YourResultName]$ci_estimates$CI_high` }
-#' }
 #'
 #' @examples
 #' trialData <- trialDataMF
@@ -76,17 +72,14 @@
 #' @export
 
 BJSM_c <- function(data, xi_prior.mean, xi_prior.sd, phi3_prior.sd, n_MCMC_chain, n.adapt,
-                   MCMC_SAMPLE, ci = 0.95, n.digits, thin = 1, BURN.IN = 100, cran_check_option = FALSE, verbose = FALSE, ...) {
-  if (cran_check_option) {
-    return("Model not fitted. Set cran_check_option = FALSE to fit a model.")
-  }
-
-  quiet = FALSE
-  progress.bar = "text"
+                   MCMC_SAMPLE, ci = 0.95, n.digits, thin = 1, BURN.IN = 100,
+                   jags.model_options = NULL, coda.samples_options = NULL, verbose = FALSE, ...) {
+  quiet <- FALSE
+  progress.bar <- "text"
 
   if (verbose == FALSE) {
-    quiet = TRUE
-    progress.bar = "none"
+    quiet <- TRUE
+    progress.bar <- "none"
   }
 
   # bug files written to temporary directory on function call to satisfy CRAN
@@ -100,7 +93,7 @@ BJSM_c <- function(data, xi_prior.mean, xi_prior.sd, phi3_prior.sd, n_MCMC_chain
 
   NUM_ARMS <- length(unique(trialData$trt1[!is.na(trialData$trt1)]))
 
-  jag <- rjags::jags.model(
+  jag <- do.call(rjags::jags.model, c(list(
     file = csnSMART_file,
     data = list(
       n = length(unique(trialData$id)),
@@ -114,14 +107,15 @@ BJSM_c <- function(data, xi_prior.mean, xi_prior.sd, phi3_prior.sd, n_MCMC_chain
       xi_prior.sd = 1 / (xi_prior.sd^2),
       phi3_prior.sd = 1 / (phi3_prior.sd^2)
     ),
-    n.chains = n_MCMC_chain, n.adapt = n.adapt, quiet = quiet, ...
-  )
+    n.chains = n_MCMC_chain, n.adapt = n.adapt, quiet = quiet, jags.model_options
+  )))
   update(jag, BURN.IN, progress.bar = progress.bar)
-  posterior_sample <- rjags::coda.samples(jag,
-    c("xi_", "phi1", "phi3", "rho"),
-    MCMC_SAMPLE,
-    thin = thin, progress.bar = progress.bar
-  )
+  posterior_sample <- do.call(rjags::coda.samples, c(list(
+    model = jag,
+    variable.names = c("xi_", "phi1", "phi3", "rho"),
+    n.iter = MCMC_SAMPLE,
+    thin = thin, progress.bar = progress.bar, coda.samples_options
+  )))
 
 
   out_post <- as.data.frame(posterior_sample[[1]])
